@@ -1,6 +1,6 @@
 /*
  Authors
- Martin Schlather, schlath@hsu-hh.de
+ Martin Schlather, martin.schlather@math.uni-goettingen.de
 
  Simulation of a random field by spectral turning bands
 
